@@ -1,7 +1,7 @@
 package Tapper::CLI::Testplan;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Handle testplans
-$Tapper::CLI::Testplan::VERSION = '5.0.7';
+$Tapper::CLI::Testplan::VERSION = '5.0.8';
 use 5.010;
 use warnings;
 use strict;
@@ -108,10 +108,12 @@ sub testplanlist
         }
         if ($c->options->{format}) {
                 use Data::Dumper;
-                given(lc($c->options->{format})) {
-                        when ('yaml') { return YAML::XS::Dump(\%inst_data)}
-                        when ('json') { return encode_json(\%inst_data)}
-                        default       { die "unknown format: ",$c->options->{format}}
+                if (lc($c->options->{format}) eq 'yaml') {
+                        return YAML::XS::Dump(\%inst_data);
+                } elsif (lc($c->options->{format}) eq 'json') {
+                        return encode_json(\%inst_data);
+                } else {
+                        die "unknown format: ",$c->options->{format};
                 }
         } else {
                 if ($c->options->{verbose}) {
@@ -285,7 +287,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Advanced Micro Devices, Inc.
+This software is Copyright (c) 2024 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
